@@ -16,6 +16,7 @@ from osc_lib.tests import utils
 from unittest import mock
 import uuid
 
+image_uuid = uuid.uuid4().hex
 deployable_created_at = '2019-06-24T00:00:00.000000+00:00'
 deployable_updated_at = '2019-06-24T11:11:11.111111+11:11'
 deployable_uuid = uuid.uuid4().hex
@@ -108,6 +109,24 @@ ACCELERATOR_REQUEST = {
     'attach_handle_info': accelerator_request_attach_handle_info,
 }
 
+attribute_created_at = '2023-05-17T00:00:00.000000+00:00'
+attribute_updated_at = '2023-05-17T11:11:11.111111+11:11'
+attribute_id = 1
+attribute_uuid = uuid.uuid4().hex
+attribute_deployable_id = 'fake_attribute_name'
+attribute_key = 'traits1'
+attribute_value = 'CUSTOM_FAKE_DEVICE'
+
+ATTRIBUTE = {
+    'created_at': attribute_created_at,
+    'updated_at': attribute_updated_at,
+    'id': attribute_id,
+    'uuid': attribute_uuid,
+    'deployable_id': attribute_deployable_id,
+    'key': attribute_key,
+    'value': attribute_value,
+}
+
 
 class TestAccelerator(utils.TestCommand):
 
@@ -116,6 +135,7 @@ class TestAccelerator(utils.TestCommand):
 
         self.app.client_manager.auth_ref = mock.MagicMock(auth_token="TOKEN")
         self.app.client_manager.accelerator = mock.MagicMock()
+        self.app.client_manager.image = mock.MagicMock()
 
 
 class FakeAcceleratorResource(fakes.FakeResource):
